#ifndef AAFractalImage_H
#define AAFractalImage_H
/*########################################################################
	File:			AAFractalImage.h
	Creation date:	25th May 2002

	Copyright 2002 Mark Williams, all rights reserved.
	Contact: mark@extrabit.com
	http://www.extrabit.com

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

########################################################################*/

/*########################################################################
	Headers
########################################################################*/

#include "rgbcolour.h"
#include "Vector2.h"

/*########################################################################
	Declarations
########################################################################*/

class FractalImage ;
class Palette ;
class Processor ;

/*########################################################################
	Class Definition
########################################################################*/

/**	AAFractalImage takes a FractalImage that has already been calculated,
 *	and adaptively anti-aliases the image.
 *	This is done by comparing each pixel with it's 8 neighbours.  If it
 *	is different to any of its neighbours, it is anti-aliased.
 *	Otherwise, it is assumed to be in a constant region, so it does not
 *	need anti-aliasing.
 */
class AAFractalImage
{
public:
	AAFractalImage (FractalImage*) ;

	void set_subpixel_gridsize (int) ;
	int inq_subpixel_gridsize (void) const { return m_subpixel_gridsize ; }

	void restart (void) ;
	bool process (void) ;

	bool inq_done (void) const { return m_done ; }
	int inq_progress (void) const { return m_progress ; }

private:
	/**	FractalImage. */
	FractalImage* m_image ;

	/**	Size of subpixel square grid.
	 *	There will be the square of this value subpixels per pixel.
	 */
	int m_subpixel_gridsize ;

	/** Flag that is set once processing is finished. */
	bool m_done ;

	/** Progress counter - increments from 0 to 100 during processing. */
	int m_progress ;

	/**	'x' offset to current pixel. */
	int m_x ;

	/**	'y' offset to current pixel. */
	int m_y ;

	/**	Pointer to current RGB pixel. */
	rgbcolour_t* m_curr_rgb_pixel ;

	/**	Position of bottom left corner of current pixel. */
	Vector2 m_curr_pixel ;

	/**	Position in fractal space of first pixel on the current row. */
	Vector2 m_rowstart ;

	/**	Offset in fractal space from a pixel to the next.
	 *	This is determined from the view transform and the image size.
	 */
	Vector2 m_xoffs ;

	/**	Offset in fractal space from a pixel in one row to the next.
	 *	This is determined from the view transform and the image size.
	 */
	Vector2 m_yoffs ;

	/** Distance from current sub-pixel row to next. */
	Vector2 m_xsuboffs ;

	/**	Distance from current sub-pixel to next sub-pixel on current sub-pixel row. */
	Vector2 m_ysuboffs ;
} ;


/*########################################################################
	End
########################################################################*/
#endif
