/*########################################################################
	FractalDlg.cpp

	Copyright 2002 Mark Williams, all rights reserved.
	Contact: mark@extrabit.com
	http://www.extrabit.com

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

########################################################################*/

#include "stdafx.h"
#include "fractalviewer.h"
#include "FractalDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CFractalDlg dialog

// Default view (used when reset button is pressed).
static double s_default_view_x = 0.0 ;
static double s_default_view_y = 0.0 ;
static double s_default_view_width = 0.0 ;
static double s_default_view_angle = 0.0 ;


CFractalDlg::CFractalDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CFractalDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CFractalDlg)
	m_zx = 0.0;
	m_zy = 0.0;
	m_view_x = 0.0;
	m_view_y = 0.0;
	m_view_width = 0.0;
	m_view_angle = 0.0;
	m_invert_u = FALSE;
	//}}AFX_DATA_INIT

	m_fractal_type = 0 ;
}


/**	This is called once at the start of the program to initialise
 *	the default view, which is the view set when the reset button is pressed.
 */
void CFractalDlg::set_default_view (double x, double y, double width, double angle)
{
	s_default_view_x = x ;
	s_default_view_y = y ;
	s_default_view_width = width ;
	s_default_view_angle = angle ;
}


void CFractalDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CFractalDlg)
	DDX_Control(pDX, IDC_FRACTAL_COMBO, m_fractal_combo);
	DDX_Text(pDX, IDC_ZX_EDIT, m_zx);
	DDX_Text(pDX, IDC_ZY_EDIT, m_zy);
	DDX_Text(pDX, IDC_VIEW_X_EDIT, m_view_x);
	DDX_Text(pDX, IDC_VIEW_Y_EDIT, m_view_y);
	DDX_Text(pDX, IDC_VIEW_WIDTH_EDIT, m_view_width);
	DDX_Text(pDX, IDC_VIEW_ANGLE_EDIT, m_view_angle);
	DDX_Check(pDX, IDC_INVERT_U_CHECK, m_invert_u);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CFractalDlg, CDialog)
	//{{AFX_MSG_MAP(CFractalDlg)
	ON_BN_CLICKED(IDC_RESET_BTN, OnResetBtn)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CFractalDlg message handlers


/////////////////////////////////////////////////////////////////////////////
BOOL CFractalDlg::OnInitDialog() 
{
	CDialog::OnInitDialog();

	m_fractal_combo.SetCurSel (m_fractal_type) ;
	
	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}


/////////////////////////////////////////////////////////////////////////////
void CFractalDlg::OnOK() 
{
	m_fractal_type = m_fractal_combo.GetCurSel() ;
	
	CDialog::OnOK();
}


/////////////////////////////////////////////////////////////////////////////
void CFractalDlg::OnResetBtn() 
{
	m_view_x = s_default_view_x ;
	m_view_y = s_default_view_y ;
	m_view_width = s_default_view_width ;
	m_view_angle = s_default_view_angle ;
	UpdateData (FALSE) ;
}
