#if !defined(AFX_FRACTALVIEWER_H__1216EC24_5FE9_4F36_97F8_DF1BFA67E7F9__INCLUDED_)
#define AFX_FRACTALVIEWER_H__1216EC24_5FE9_4F36_97F8_DF1BFA67E7F9__INCLUDED_
/*########################################################################
	FractalViewer.h

	Copyright 2002 Mark Williams, all rights reserved.
	Contact: mark@extrabit.com
	http://www.extrabit.com

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

########################################################################*/

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#ifndef __AFXWIN_H__
	#error include 'stdafx.h' before including this file for PCH
#endif

#include "Vector2.h"
#include "FractalImage.h"
#include "ProgressiveImageGen.h"
#include "FastImageGen.h"
#include "AAFractalImage.h"
#include "Palette.h"

#include "resource.h"       // main symbols


/////////////////////////////////////////////////////////////////////////////
// CFractalViewerApp:
// See FractalViewer.cpp for the implementation of this class
//

/**	The MFC application class.
 *	This stores all the application state data.
 */
class CFractalViewerApp : public CWinApp
{
public:
	CFractalViewerApp();

	FractalImage* inq_image (void) { return &m_image ; }

	void image_resized (void) ;
	void restart (void) ;

	void update_status_bar (void) ;
	void set_processor (int fractal_type) ;

// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CFractalViewerApp)
	public:
	virtual BOOL InitInstance();
	virtual BOOL OnIdle(LONG lCount);
	//}}AFX_VIRTUAL

public:
	//{{AFX_MSG(CFractalViewerApp)
	afx_msg void OnAppAbout();
	afx_msg void OnViewOptions();
	afx_msg void OnPaletteRandomise();
	afx_msg void OnViewFractals();
	afx_msg void OnPaletteMainCol();
	afx_msg void OnPaletteBright();
	afx_msg void OnPalettePastel();
	afx_msg void OnPaletteMonochrome();
	afx_msg void OnPaletteWhite();
	afx_msg void OnUpdatePaletteBright(CCmdUI* pCmdUI);
	afx_msg void OnUpdatePalettePastel(CCmdUI* pCmdUI);
	afx_msg void OnUpdatePaletteMonochrome(CCmdUI* pCmdUI);
	afx_msg void OnUpdatePaletteWhite(CCmdUI* pCmdUI);
	afx_msg void OnExportJpg();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()

private:
	void set_imagegen (void) ;
	void update_palette (void) ;
	void export_image (CString path, int width, int height, int aa_gridsize) ;

private:
	/**	The FractalImage being calculated. */
	FractalImage m_image ;

	/**	If true, ProgressiveImageGen is used as the image generator.
	 *	Otherwise, FastImageGen is used.
	 */
	bool m_progressive ;

	/**	Points to the current image generator. */
	ImageGen* m_imagegen ;

	/**	ProgressiveImageGen is used when image is being generated progressively. */
	ProgressiveImageGen m_progressive_imagegen ;

	/**	FastImageGen is used when the image is being generated non-progressively. */
	FastImageGen m_fast_imagegen ;

	/** Anti-aliasing uses an AAFractalImage. */
	AAFractalImage m_aa_image ;

	/**	Palette for colouring image. */
	Palette m_palette ;

	/** Fractal type - indicates which of the derived Processor
	 *	objects is set in 'm_image'.
	 *	The values of this must match the values entered in the fractal
	 *	type combo control on the Fractals panel.
	 *	0 - MandelbrotProcessor
	 *	1 - InvMandelbrotProcessor
	 *	2 - Z3Processor
	 *	3 - InvZ3Processor
	 *	4 - Z2PlusZProcessor
	 *	5 - InvZ2PlusZProcessor
	 */
	int m_fractal_type ;

	/**	Currently displayed iteration - this is used to determine when
	 *	to update the status bar.
	 */
	int m_progress ;
};


/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_FRACTALVIEWER_H__1216EC24_5FE9_4F36_97F8_DF1BFA67E7F9__INCLUDED_)
