#ifndef Matrix33_H
#define Matrix33_H
/*########################################################################
	File:			Matrix33.h
	Creation date:	25th May 2002

	Copyright 2002 Mark Williams, all rights reserved.
	Contact: mark@extrabit.com
	http://www.extrabit.com

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

########################################################################*/

/*########################################################################
	Headers
########################################################################*/

/*########################################################################
	Declarations
########################################################################*/

class Vector2 ;

/*########################################################################
	Class Definition
########################################################################*/

/**	3x3 Matrix
 *	Used to represent a homogeneous 2D affine transform.
 *	The standard coordinate space has the Y-axis pointing up.
 *	Angles are measured in radians, and increase ACW.
 */
class Matrix33
{
public:
	Matrix33 (void) ;

	// Initialisers that take no arguments.
	enum Matrix33_init {IDENTITY, ZERO} ;
	Matrix33 (Matrix33_init) ;

	// Initialisers that take a double argument.
	enum Matrix33_init_d {ROTATE, SCALE} ;
	Matrix33 (Matrix33_init_d, double) ;

	// Initialisers that take a ZVector2 argument.
	enum Matrix33_init_v {TRANSLATE, SCALE_XY} ;
	Matrix33 (Matrix33_init_v, const Vector2&) ;

	void set_zero (void) ;
	void set_identity (void) ;
	void set_translation (const Vector2&) ;
	void set_rotation (double angle) ;
	void set_rotation (double angle, const Vector2& origin) ;
	void set_scale (double scale) ;
	void set_scale (const Vector2& scale_xy) ;

	void transform (Vector2*) const ;

	Matrix33 operator* (const Matrix33&) const ;

private:
	/**	Matrix elements, [rows][cols] */
	double m_elements[3][3] ;
} ;


/*########################################################################
	End
########################################################################*/
#endif
