#ifndef Palette_H
#define Palette_H
/*########################################################################
	File:			Palette.h
	Creation date:	25th May 2002

	Copyright 2002 Mark Williams, all rights reserved.
	Contact: mark@extrabit.com
	http://www.extrabit.com

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

########################################################################*/

/*########################################################################
	Headers
########################################################################*/

#include "rgbcolour.h"

/*########################################################################
	Declarations
########################################################################*/

/*########################################################################
	Type Definitions
########################################################################*/

/**	Enumerated type for the types of colours that can be randomly generated
 *	to fill the palette.
 */
enum palette_t
{
	PALETTE_BRIGHT = 0,
	PALETTE_PASTEL,
	PALETTE_MONOCHROME,
	PALETTE_WHITE
} ;

/*########################################################################
	Class Definition
########################################################################*/

/**	Holds a fixed size colour palette
 */
class Palette
{
public:
	Palette (int ncolours) ;
	~Palette (void) ;

	int inq_ncolours (void) const { return m_ncolours ; }
	rgbcolour_t* inq_colours (void) const { return m_colours ; }
	float* inq_linear_colours (void) const { return m_linear_colours ; }

	void resize (int) ;
	void randomise (void) ;

	palette_t inq_type (void) const { return m_type ; }
	void set_type (palette_t type) { m_type = type ; }

	rgbcolour_t inq_main_colour (void) const { return m_main_colour ; }
	void set_main_colour (rgbcolour_t col) ;

	double gamma_correct (double linear_col) const ;

private:
	void init (int ncolours) ;
	void randomise_bright (void) ;
	void randomise_pastel (void) ;
	void randomise_monochrome (void) ;
	void set_white (void) ;
	void update_linear_colours (void) ;

private:
	/**	Palette type.  This determines the types of colours that
	 *	are randomly generated.
	 */
	palette_t m_type ;

	/**	Specifies the last colour in the palette, which is used for pixels that have
	 *	reached the maximum number of iterations without diverging.
	 */
	rgbcolour_t m_main_colour ;

	/**	Number of colours in the palette. */
	int m_ncolours ;

	/**	The colours in the palette.
	 *	The last colour in the palette will be 'm_main_colour'.
	 *	The size of this array is 'm_ncolours'.
	 */
	rgbcolour_t* m_colours ;

	/**	The colours in the palette, transformed into a linear colour space
	 *	for anti-aliasing.
	 *	Each colour is stored as 3 floats, in the order red, green, blue.
	 *	Each colour component is in the range [0,1]
	 *	The size of this array is therefore 3 x 'm_ncolours'
	 */
	float* m_linear_colours ;
} ;


/*########################################################################
	End
########################################################################*/
#endif
