#ifndef Processor_H
#define Processor_H
/*########################################################################
	File:			Processor.h
	Creation date:	25th May 2002

	Copyright 2002 Mark Williams, all rights reserved.
	Contact: mark@extrabit.com
	http://www.extrabit.com

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

########################################################################*/

/*########################################################################
	Headers
########################################################################*/

/*########################################################################
	Declarations
########################################################################*/

class ComplexNumber ;

/*########################################################################
	Class Definition
########################################################################*/

/**	Base class for fractal image generators.
 *	Derived classes must implement both methods.  This is required
 *	for performance reasons, since ProgressiveImageGen needs to be
 *	able to iterate one step at a time, and FastImageGen and AAFractalImage
 *	process each pixel to completion.  This can be done much more efficiently
 *	with one function call, rather than repeatedly calling iterate().
 */
class Processor
{
public:
	virtual ComplexNumber iterate (const ComplexNumber& z, const ComplexNumber& u) const = 0 ;
	virtual unsigned short iterate_to_end (const ComplexNumber& initial_z, const ComplexNumber& u, unsigned short max_itns) const = 0 ;
} ;


/*########################################################################
	End
########################################################################*/
#endif
