#ifndef Vector2_H
#define Vector2_H
/*########################################################################
	File:			Vector2.h
	Creation date:	25th May 2002

	Copyright 2002 Mark Williams, all rights reserved.
	Contact: mark@extrabit.com
	http://www.extrabit.com

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

########################################################################*/

/*########################################################################
	Headers
########################################################################*/

/*########################################################################
	Declarations
########################################################################*/

/*########################################################################
	Class Definition
########################################################################*/

/**	2D Vector
 */
class Vector2
{
public:
	Vector2 (void) { m_x = m_y = 0.0 ; }
	Vector2 (double x, double y) { m_x = x ; m_y = y ; }

	const double& x (void) const { return m_x ; }
	const double& y (void) const { return m_y ; }
	double& x (void) { return m_x ; }
	double& y (void) { return m_y ; }

	double distance_to (const Vector2&) const ;

	const Vector2& operator+= (const Vector2&) ;
	Vector2 operator+ (const Vector2&) const ;
	Vector2 operator- (const Vector2&) const ;
	Vector2 operator* (double) const ;
	Vector2 operator/ (double) const ;

private:
	double m_x ;
	double m_y ;
} ;


/**	Adds the given Vector2 to this one.
 */
inline const Vector2& Vector2::operator+= (const Vector2& v)
{
	m_x += v.m_x ;
	m_y += v.m_y ;
	return *this ;
}


/**	@return Returns the sum of this Vector2 and the given one.
 */
inline Vector2 Vector2::operator+ (const Vector2& v) const
{
	return Vector2 (m_x + v.m_x, m_y + v.m_y) ;
}


/**	@return Returns the difference between this Vector2 and the given one.
 */
inline Vector2 Vector2::operator- (const Vector2& v) const
{
	return Vector2 (m_x - v.m_x, m_y - v.m_y) ;
}


/*########################################################################
	End
########################################################################*/
#endif
